#!/bin/bash
#
# Copyright 2024 Nordix Foundation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

set -o errexit  # Exit on most errors
set -o nounset  # Disallow expansion of unset variables
set -o pipefail # Use last non-zero exit code in a pipeline
set -o xtrace   # Trace logging

#############################################################################################################################
################################################ M A I N ####################################################################
#############################################################################################################################
cd "$WORKSPACE"

# Check if cps repository directory exists
if [ -d "cps" ]; then
  # If it exists, wipe the directory
  echo "wiping the old cps repository..."
  rm -rf cps
fi

# Check if build-logs exists
if [ -d "build-logs" ]; then
  # If it exists, wipe the directory
  echo "wiping the old build-logs directory..."
  rm -rf "build-logs"
fi

mkdir "build-logs"

# Close the cps repository
git clone https://gerrit.nordix.org/onap/cps
cd cps

# Build latest images
mvn -B clean install -DskipTests -Dcheckstyle.skip

working_directory=$(pwd)

# Provide execute permission to runner script
chmod 777 "$working_directory/k6-tests/run-k6-tests.sh"

# Run all k6 tests and save the logs
"$working_directory/k6-tests/run-k6-tests.sh" 2>&1 | tee "$WORKSPACE/build-logs/k6-build.log"
